@@ -13,7 +13,7 @@ package Printer::ESCPOS;
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
 #
-our $VERSION = '0.012'; # VERSION
+our $VERSION = '0.013'; # VERSION
 
 # Dependencies
 use 5.010;
@@ -154,25 +154,63 @@ Printer::ESCPOS - Interface for all thermal, dot-matrix and other receipt printe
 
 =head1 VERSION
 
-version 0.012
+version 0.013
 
 =head1 SYNOPSIS
 
 If you are just starting up with POS RECEIPT Printers, you must first refer to L<Printer::ESCPOS::Manual> to get started.
 
 Printer::ESCPOS provides four different types of printer connections to talk to a ESCPOS printer. 
-Among these connection types 'Serial', 'Network', 'File' are already implemented in this module. 'USB' type using L<Device::USB> module is under development. In the meantime most of the printing tasks for USB connected printer can be achieved using the 'File' connection mode for usb connected ESCPOS printers.
+As of v0.012 I<driverTypes> B<Serial>, B<Network>, B<File> and B<USB> are all implemented in this module. 'USB' driverType is not supported prior to v0.012. 
+
+=head2 USB Printer
+
+B<USB> I<driverType> allows you to talk to your Printer using the I<vendorId> and I<productId> values for your printer. These can be retrieved using lsusb command
+
+     shantanu@shantanu-G41M-ES2L:~/github$ lsusb
+     . . .
+     Bus 003 Device 002: ID 1504:0006  
+     . . .
+
+The output gives us the I<vendorId> 0x1504 and I<productId> 0x0006
+
+For USB Printers L<Printer::ESCPOS> uses a default I<endPoint> of 0x01 and a default I<timeout> of
+1000, however these can be specified manually in case your printer requires a different value.
 
      use Printer::ESCPOS;
  
-     use Data::Dumper; # Just to get dumps of status functions.
+     my $vendorId  = 0x1504;
+     my $productId = 0x0006;
+     my $device = Printer::ESCPOS->new(
+         driverType     => 'USB',
+         vendorId       => $vendorId,
+         productId      => $productId,
+     );
  
+     $device->printer->printAreaWidth( nL => 0, nH => 1);
+     $device->printer->text("Print Area Width Modified\n");
+     $device->printer->printAreaWidth(); # Reset to default
+     $device->printer->text("print area width reset\n");
+     $device->printer->tab();
+     $device->printer->underline(1);
+     $device->printer->text("underline on\n");
+     $device->printer->invert(1);
+     $device->printer->text("Inverted Text\n");
+     $device->printer->justification('right');
+     $device->printer->text("Right Justified\n");
+     $device->printer->upsideDown(1);
+     $device->printer->text("Upside Down\n");
+     $device->printer->cutPaper();
+ 
+     $device->printer->print(); # Dispatch the above commands from module buffer to the Printer. 
+
+=head2 Network Printer
+
+For Network Printers $port is 9100 in most cases but might differ depending on how 
+you have configured your printer
+
+     use Printer::ESCPOS;
  
-     #########################################################
-     BEGIN: Network Printer
-     #########################################################
-     # For Network Printers $port is 9100 in most cases but might differ depending on how 
-     # you have configured your printer
      my $printer_id = '192.168.0.10';
      my $port       = '9100';
      my $device = Printer::ESCPOS->new(
@@ -180,7 +218,6 @@ Among these connection types 'Serial', 'Network', 'File' are already implemented
          deviceIp   => $printer_ip,
          devicePort => $port,
      );
-     $device->printer->init(); # This calls the initialization functions for your printer.
  
      # These commands won't actually send anything to the printer but will store all the 
      # merged data including control codes to module buffer.
@@ -201,21 +238,22 @@ Among these connection types 'Serial', 'Network', 'File' are already implemented
  
      $device->printer->print(); # Dispatch the above commands from module buffer to the Printer. 
                                 # This command takes care of read text buffers for the printer.
+
+=head2 Serial Printer
+
+Use the Serial mode for local printer connected on serial port(or a printer connected via 
+a physical USB port in USB to Serial mode), check syslog(Usually under E<sol>varE<sol>logE<sol>syslog) 
+for what device file was created for your printer when you connect it to your system(For 
+plug and play printers).
+
+     use Printer::ESCPOS;
+     use Data::Dumper; # Just to get dumps of status functions supported for Serial driverType.
  
- 
-     #########################################################
-     BEGIN: Serial Printer
-     #########################################################
-     # Use the Serial mode for local printer connected on serial port(or a printer connected via 
-     # a physical USB port in USB to Serial mode), check syslog(Usually under /var/log/syslog) 
-     # for what device file was created for your printer when you connect it to your system(For 
-     # plug and play printers).
      my $path = '/dev/ttyACM0';
      $device = Printer::ESCPOS->new(
          driverType     => 'Serial',
          deviceFilePath => $path,
      );
-     $device->printer->init(); # This calls the initialization functions for your printer.
  
      say Dumper $device->printer->printerStatus();
      say Dumper $device->printer->offlineStatus();
@@ -228,19 +266,27 @@ Among these connection types 'Serial', 'Network', 'File' are already implemented
      $device->printer->text("Bold Text Off\n");
  
      $device->printer->print();
+
+=head2 File(Direct to Device File) Printer
+
+A 'File' driver is similar to the 'Serial' driver in all functionality except that it 
+doesn't support the status functions for the printer. i.e. you will not be able to use 
+printerStatus, offlineStatus, errorStatus or paperSensorStatus functions
+
+     use Printer::ESCPOS;
  
- 
-     #########################################################
-     BEGIN: File(Direct to Device File) Printer
-     #########################################################
-     # A 'File' driver is similar to the 'Serial' driver in all functionality except that it 
-     # doesn't support the status functions for the printer. i.e. you will not be able to use 
-     # printerStatus, offlineStatus, errorStatus or paperSensorStatus functions
      my $path = '/dev/usb/lp0';
      $device = Printer::ESCPOS->new(
          driverType     => 'File',
          deviceFilePath => $path,
      );
+ 
+     $device->printer->bold(1);
+     $device->printer->text("Bold Text\n");
+     $device->printer->bold(0);
+     $device->printer->text("Bold Text Off\n");
+ 
+     $device->printer->print();
 
 =head1 DESCRIPTION
 
@@ -250,8 +296,20 @@ You can use this module for all your ESC-POS Printing needs. If some of your pri
 
 =head2 driverType
 
-"Required attribute". The driver type to use for your printer. This can be B<File>, B<Network> or B<Serial>. B<USB> driver is not implemented yet.
-If you choose B<File> or B<Serial> driver, you must provide the I<deviceFilePath>, for B<Network> driver you must provide the I<printerIp> and I<printerPort>.
+"Required attribute". The driver type to use for your printer. This can be B<File>, B<Network>, B<USB> or B<Serial>. 
+If you choose B<File> or B<Serial> driver, you must provide the I<deviceFilePath>, 
+for B<Network> I<driverType> you must provide the I<printerIp> and I<printerPort>,
+For USB I<driverType> you must provide I<vendorId> and I<productId>.
+
+USB driver type:
+
+    my $vendorId  = 0x1504;
+    my $productId = 0x0006;
+    my $device = Printer::ESCPOS->new(
+        driverType => 'USB'
+        vendorId   => $vendorId,
+        productId  => $productId,
+    );
 
 Network driver type:
 
@@ -281,14 +339,14 @@ File driver type:
 
 =head2 profile
 
-There are minor differences in ESC POS printers across different brands and models in terms of specifications and extra features. For using special features of a particular brand you may create a sub class in the name space Printer::ESCPOS::Profiles::* and load your profile here. I would recommend extending  Generic ( L<Printer::ESCPOS::Profiles::Generic> ).
+There are minor differences in ESC POS printers across different brands and models in terms of specifications and extra features. For using special features of a particular brand you may create a sub class in the name space Printer::ESCPOS::Profiles::* and load your profile here. I would recommend extending the Generic Profile( L<Printer::ESCPOS::Profiles::Generic> ).
 Use the following classes as examples.
 L<Printer::ESCPOS::Profiles::Generic>
 L<Printer::ESCPOS::Profiles::SinocanPSeries>
 
-Note that your driver class will have to implement the Printer::ESCPOS::Roles::Profile Interface. This is a Moose Role and can be included in your class with the following line.
+Note that your driver class will have to implement the Printer::ESCPOS::Roles::Profile Interface. This is a L<Moo::Role> and can be included in your class with the following line.
 
-    use Moose;
+    use Moo;
     with 'Printer::ESCPOS::Roles::Profile';
 
 By default the generic profile is loaded but if you have written your own Printer::ESCPOS::Profile::* class and want to override the generic class pass the I<profile> Param during object creation.
@@ -324,19 +382,24 @@ Set this value to 1 if you are connecting your printer using the USB Cable but i
 
 =head2 vendorId
 
-USB Printers VendorId. use lsusb command to get this value
+This is a required param for *USB* ~driverType~. It contains the USB printer's Vendor ID when using *USB* ~driverType~. Use lsusb command to get this value for your printer.
 
 =head2 productId
 
-USB Printers product Id. use lsusb command to get this value
+This is a required param for *USB* ~driverType~. It contains the USB printer's product Id when using *USB* ~driverType~. Use lsusb command to get this value for your printer.
 
 =head2 endPoint
 
-USB endPoint to write to.
+This is a optional param for *USB* ~driverType. It contains the USB endPoint for L<Device::USB> to write to if the value is not 0x01 for your printer. Get it using the following command:
+
+    shantanu@shantanu-G41M-ES2L:~$ sudo lsusb -vvv -d 1504:0006 | grep bEndpointAddress | grep OUT
+            bEndpointAddress     0x01  EP 1 OUT
+
+Replace 1504:0006 with your own printer's vendor id and product id in the above command.
 
 =head2 timeout
 
-Timeout for bulk write functions for the USB printer.
+Timeout for bulk write functions for the USB printer. Optional param.
 
 =head2 printer
 
